==> haskell-constraints-0.10.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.10.1
id: constraints-0.10.1-miVrp1qFrZ6QOjd0CHnZ1
key: constraints-0.10.1-miVrp1qFrZ6QOjd0CHnZ1
license: BSD-2-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
abi: 3f5028833f72935f18981a3ac5118f7e
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Nat Data.Constraint.Symbol
    Data.Constraint.Unsafe
import-dirs: /usr/lib/ghc-8.4.3/site-local/constraints-0.10.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/constraints-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/constraints-0.10.1
hs-libraries: HSconstraints-0.10.1-miVrp1qFrZ6QOjd0CHnZ1
depends:
    base-4.11.1.0 binary-0.8.5.1 deepseq-1.4.3.0 ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg mtl-2.2.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-constraints-0.10.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-constraints.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: constraints
version: 0.10.1
id: constraints-0.10.1-IE9vMNLUVKu1NZUbyRRshE
key: constraints-0.10.1-IE9vMNLUVKu1NZUbyRRshE
license: BSD-2-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/constraints/
synopsis: Constraint manipulation
description:
    GHC 7.4 gave us the ability to talk about @ConstraintKinds@. They stopped crashing the compiler in GHC 7.6.
    .
    This package provides a vocabulary for working with them.
category: Constraints
abi: 3107ea80f55314b1cd228a03d16e411a
exposed: True
exposed-modules:
    Data.Constraint Data.Constraint.Deferrable Data.Constraint.Forall
    Data.Constraint.Lifting Data.Constraint.Nat Data.Constraint.Symbol
    Data.Constraint.Unsafe
import-dirs: /usr/lib/ghc-8.6.1/site-local/constraints-0.10.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/constraints-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/constraints-0.10.1
hs-libraries: HSconstraints-0.10.1-IE9vMNLUVKu1NZUbyRRshE
depends:
    base-4.12.0.0 binary-0.8.6.0 deepseq-1.4.4.0 ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
haddock-interfaces: /usr/share/doc/haskell-constraints/html/constraints.haddock
haddock-html: /usr/share/doc/haskell-constraints/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
